@@ -1,16 +1,17 @@
 """A simple projection/backprojection cycle implementation."""
+
 import mrcfile
+import napari
 import torch
 from scipy.stats import special_ortho_group
 
-from torch_fourier_slice import project_3d_to_2d, backproject_2d_to_3d
-
+from torch_fourier_slice import backproject_2d_to_3d, project_3d_to_2d
 
 N_IMAGES = 1000
 torch.manual_seed(42)
 
 # load a volume and normalise
-volume = torch.tensor(mrcfile.read('/Users/burta2/data/4v6x_bin4.mrc'))
+volume = torch.tensor(mrcfile.read("/Users/burta2/data/4v6x_bin4.mrc"))
 volume -= torch.mean(volume)
 volume /= torch.std(volume)
 
@@ -36,12 +37,10 @@ reconstruction -= torch.mean(reconstruction)
 reconstruction = reconstruction / torch.std(reconstruction)
 
 # visualise
-import napari
-
 viewer = napari.Viewer()
-viewer.add_image(projections.numpy(), name='projections')
+viewer.add_image(projections.numpy(), name="projections")
 
 viewer = napari.Viewer(ndisplay=3)
-viewer.add_image(volume.numpy(), name='ground truth')
-viewer.add_image(reconstruction.numpy(), name='reconstruction')
+viewer.add_image(volume.numpy(), name="ground truth")
+viewer.add_image(reconstruction.numpy(), name="reconstruction")
 napari.run()
